<?php /**
 * Register color schemes for Whitish Lite.
 *
 * Can be filtered with {@see 'whitish_lite_color_schemes'}.
 *
 * The order of colors in a colors array:
 * @since Whitish Lite 1.1
 *
 * @return array An associative array of color scheme options.
 */
if ( ! function_exists( 'whitish_lite_get_color_schemes' ) ) :
	function whitish_lite_get_color_schemes() {
		return apply_filters( 'whitish_lite_color_schemes', array(
			'default_color' => array(
				'label'  => __( '--Default--', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#c69f70',
					'#c69f70',
					'#c69f70',

				),
			),
			'dark'    => array(
				'label'  => __( 'Dark', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#111111',
					'#111111',
					'#111111',

				),
			),
			'yellow'  => array(
				'label'  => __( 'Yellow', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#ffae00',
					'#ffae00',
					'#ffae00',

				),
			),
			'pink'    => array(
				'label'  => __( 'Pink', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#f52e5d',
					'#f52e5d',
					'#f52e5d',


				),
			),
			'blue'   => array(
				'label'  => __( 'Blue', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#009eed',
					'#009eed',
					'#009eed',

				),
			),
			'purple'   => array(
				'label'  => __( 'Purple', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#9651cc',
					'#9651cc',
					'#9651cc',

				),
			),
			'vanburenborwn'    => array(
				'label'  => __( 'Van Buren Brown', 'whitish-lite' ),
				'colors' => array(
					'#c69f70',
					'#a57a6b',
					'#a57a6b',
					'#a57a6b',


				),
			),
		) );
	}
endif;

if ( ! function_exists( 'whitish_lite_get_color_scheme' ) ) :
/**
 * Get the current Whitish Lite color scheme.
 *
 * @since Whitish Lite 1.0
 *
 * @return array An associative array of either the current or default color scheme hex values.
 */
function whitish_lite_get_color_scheme() {
	$color_scheme_option = get_theme_mod( 'color_scheme', 'default_color' );
	$color_schemes       = whitish_lite_get_color_schemes();

	if ( array_key_exists( $color_scheme_option, $color_schemes ) ) {

		return $color_schemes[ $color_scheme_option ]['colors'];
	}

	return $color_schemes['default_color']['colors'];
}
endif;

if ( ! function_exists( 'whitish_lite_get_color_scheme_choices' ) ) :
/**
 * Returns an array of color scheme choices registered for Whitish Lite.
 *
 * @since Whitish Lite 1.0
 *
 * @return array Array of color schemes.
 */
function whitish_lite_get_color_scheme_choices() {
	$color_schemes                = whitish_lite_get_color_schemes();
	$color_scheme_control_options = array();

	foreach ( $color_schemes as $color_scheme => $value ) {
		$color_scheme_control_options[ $color_scheme ] = $value['label'];
	}

	return $color_scheme_control_options;
}
endif; // whitish_lite_get_color_scheme_choices

if ( ! function_exists( 'whitish_lite_sanitize_color_scheme' ) ) :
/**
 * Sanitization callback for color schemes.
 *
 * @since Whitish Lite 1.0
 *
 * @param string $value Color scheme name value.
 * @return string Color scheme name.
 */
function whitish_lite_sanitize_color_scheme( $value ) {
	$color_schemes = whitish_lite_get_color_scheme_choices();

	if ( ! array_key_exists( $value, $color_schemes ) ) {
		$value = 'default_color';
	}

	return $value;
}
endif; // whitish_lite_sanitize_color_scheme

if ( ! function_exists( 'whitish_lite_color_scheme_css' ) ) :
	/**
	 * Enqueues front-end CSS for color scheme.
	 *
	 * @since Whitish Lite 1.0
	 *
	 * @see wp_add_inline_style()
	 */
	function whitish_lite_color_scheme_css() {
		$color_scheme_option = get_theme_mod( 'color_scheme', 'default_color' );

		// Don't do anything if the default_color color scheme is selected.
		if ( 'default_color' === $color_scheme_option ) {
			return;
		}

		$color_scheme = whitish_lite_get_color_scheme();

		$colors = array(
			'site_page_nav_link_title_color'        => $color_scheme[3],
			'whitish_lite_button_color'    => $color_scheme[3],
			'whitish_lite_woocommerce_color'        => $color_scheme[3],
		);

		$color_scheme_css = whitish_lite_get_color_scheme_css( $colors);

		wp_add_inline_style( 'whitish-lite-style', $color_scheme_css);
	}
	add_action( 'wp_enqueue_scripts', 'whitish_lite_color_scheme_css' );

endif;

if ( ! function_exists( 'whitish_lite_customize_control_js' ) ) :
	/**
	 * Binds JS listener to make Customizer color_scheme control.
	 *
	 * Passes color scheme data as whitish-lite-colorScheme global.
	 *
	 * @since Whitish Lite 1.0
	 */
	function whitish_lite_customize_control_js() {
		wp_enqueue_script( 'whitish-lite-color-scheme-control', get_template_directory_uri() . '/assets/js/color-scheme-control.js', array( 'customize-controls' ), '20140108', true );
		wp_localize_script( 'whitish-lite-color-scheme-control', 'whitish_lite_colorScheme', whitish_lite_get_color_schemes() );
	}
	add_action( 'customize_controls_enqueue_scripts', 'whitish_lite_customize_control_js' );

endif;

if ( ! function_exists( 'whitish_lite_customize_preview_js' ) ) :
	/**
	 * Binds JS handlers to make the Customizer preview reload changes asynchronously.
	 *
	 * @since Whitish Lite 1.0.4
	 */
	function whitish_lite_customize_preview_js() {
		wp_enqueue_script( 'whitish-lite-customize-preview', get_template_directory_uri() . '/assets/js/customize-preview.js', array( 'customize-preview' ), '20130508', true );
	}

	add_action( 'customize_preview_init', 'whitish_lite_customize_preview_js' );
endif;

if ( ! function_exists( 'whitish_lite_color_scheme_color' ) ) :
	function whitish_lite_color_scheme_color($color_scheme) {
		if ($color_scheme == 'default_color') {
			$color = '#c69f70';
		}

		else if ($color_scheme == 'yellow') {
			$color = '#ffae00';
		}

		else if ($color_scheme == 'dark') {
			$color = '#111111';
		}

		else if ($color_scheme == 'pink') {
			$color = '#f52e5d';
		}

		else if ($color_scheme == 'blue') {
			$color = '#009eed';
		}

		else if ($color_scheme == 'vanburenborwn') {
			$color = '#a57a6b';
		}

		else {
			$color = '#c69f70';
		}

		return $color;
	}
endif;

if ( ! function_exists( 'whitish_lite_get_color_scheme_css' ) ) :
/**
 * Returns CSS for the color schemes.
 *
 * @since Whitish Lite 1.0
 *
 * @param array $colors Color scheme colors.
 * @return string Color scheme CSS.
 */
function whitish_lite_get_color_scheme_css( $colors ) {
	$colors = wp_parse_args( $colors, array(
		'site_page_nav_link_title_color'        => '#c69f70',
		'whitish_lite_button_color'    => '#c69f70',
		'whitish_lite_woocommerce_color'        => '#c69f70',
	) );
	$color_scheme = get_theme_mod('color_scheme');
	$color_scheme_color = whitish_lite_color_scheme_color($color_scheme);
	$site_link_color = get_theme_mod('site_page_nav_link_title_color');
	$button_color = get_theme_mod('whitish_lite_button_color');
	$woocommerce_color = get_theme_mod('whitish_lite_woocommerce_color');
	$css = "

			.go-to-top a
			{
			   border: 2px solid {$color_scheme_color} ;
			   color: {$color_scheme_color} ;
			}
			.go-to-top a:hover
			{
			   background-color: {$color_scheme_color} ;
			}

			#secondary .widget-title
			{
			   border-top: 2px solid {$color_scheme_color} ;
			}

			.search-submit
			{
			   background-color: {$color_scheme_color} ;
			   border: 1px solid {$color_scheme_color} ;
			}

			.cat-links a
			 {
				background: {$site_link_color};
				border-bottom: 1px solid {$site_link_color};
			}

			a,
			ul li a:hover,
			ol li a:hover,
			.top-header .widget_contact ul li a:hover,
			.entry-title a:hover,
			.entry-title a:focus,
			.entry-title a:active,
			.entry-meta span:hover,
			.entry-meta a:hover,
			.cat-links,
			.cat-links a,
			.tag-links,
			.tag-links a,
			.entry-meta .entry-format a,
			.entry-format:before,
			.entry-meta .entry-format:before,
			.entry-header .entry-meta .entry-format:before,
			.widget ul li a:hover,
			.widget-title a:hover,
			.widget_contact ul li a:hover,
			.site-info .copyright a:hover,
			#footer-navigation a:hover,
			#colophon .widget ul li a:hover
			{
				color: {$site_link_color};
			}

			.main-navigation a:hover,
			.main-navigation ul li.current-menu-item a,
			.main-navigation ul li.current_page_ancestor a,
			.main-navigation ul li.current-menu-ancestor a,
			.main-navigation ul li.current_page_item a,
			.main-navigation ul li:hover a,
			.main-navigation ul li ul li a:hover,
			.main-navigation ul li ul li:hover a,
			.main-navigation ul li.current-menu-item ul li a:hover,
			.header-search:hover, .header-search-x:hover
			{
				color: {$site_link_color};
			}

			.main-navigation li.menu-item-has-children > a:hover:after
			{
				color: {$site_link_color};
			}

			.site-info .social-links a{
				background: {$site_link_color};
				border: 1px solid {$site_link_color};
			}


			ul.default-wp-page li a {
				color: {$site_link_color};
			}


			::selection {
				background: {$site_link_color};
				color: #fff;
			}

			::-moz-selection {
				background: {$site_link_color};
				color: #fff;
			}

			.screen-reader-text:hover,
			.screen-reader-text:active,
			.screen-reader-text:focus {
				background-color: #f1f1f1;
				color: {$site_link_color};
			}

			input[type='reset'],
			input[type='button'],
			input[type='submit']{
				background-color: {$button_color};
			}

			input#submit {
				background-color: {$button_color};
			}

			.entry-footer a.more-link{
			background: {$button_color};
			border: 1px solid {$button_color};
			}

			.btn-default:hover {
			    background-color: {$button_color};
			    border: 1px solid {$button_color};
			}

			.btn-default:hover,
			.vivid,
			 {
				background-color: {$button_color};
				border: 1px solid {$button_color};
			}

			#colophon .widget-title:after {
				background-color: {$button_color};
			}

			.light-color:hover,
			.vivid:hover {
				background-color: #fff;
				border: 1px solid #fff;
			}

			#bbpress-forums .bbp-topics a:hover {
			color: {$button_color};
			}
			.bbp-submit-wrapper button.submit {
				background-color: {$button_color};
				border: 1px solid {$button_color};
			}

			.woocommerce #respond input#submit,
			.woocommerce a.button,
			.woocommerce button.button,
			.woocommerce input.button,
			.woocommerce #respond input#submit.alt,
			.woocommerce a.button.alt,
			.woocommerce button.button.alt,
			.woocommerce input.button.alt,
			.woocommerce-demo-store p.demo_store {
				background-color: {$woocommerce_color};
			}
			.woocommerce .woocommerce-message:before {
				color: {$woocommerce_color};
			}";
	return whitish_lite_sanitize_css($css);
}
endif;

if ( ! function_exists( 'whitish_lite_color_scheme_css_template' ) ) :

	function whitish_lite_color_scheme_css_template() {
		$colors = array(

			// Color Styles
			'site_page_nav_link_title_color'        => '{{ data.site_page_nav_link_title_color }}',
			'whitish_lite_button_color'    => '{{ data.whitish_lite_button_color }}',
			'whitish_lite_woocommerce_color'        => '{{ data.whitish_lite_woocommerce_color }}',
		);
		?>
		<script type="text/html" id="tmpl-whitish-lite-color-scheme">
			<?php echo esc_attr(whitish_lite_get_color_scheme_css( $colors )); ?>
		</script>
	<?php
	}
	add_action( 'customize_controls_print_footer_scripts', 'whitish_lite_color_scheme_css_template' );
endif;